==================================
Welcome to Serpyco's documentation
==================================

.. highlight: python

.. include:: ../README.rst

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    getting_started
    benchmark
    api